@@ -5,15 +5,14 @@ from Posit.utils.prepare import prepare_data, download_data
 
 
 def print_answer(user_input, best_mol, rmsd, score, pdb_id, idx):
-    print_list = []
+    print_list = ['Your score of Exercise %s : %s/10' % ((idx + 1), score)]
     if user_input != best_mol:
         print_list.append('\nMol %s RMSD: %s' % (user_input, rmsd[user_input]))
         print_list.append('Best Mol: %s' % best_mol)
-        print_list.append('Your score of Exercise_%s: %s' % ((idx + 1), '待开发'))
     else:
         print_list.append('\nCorrect answer, Prefect!')
 
-    print_list.append('PDB_ID: %s' % pdb_id)
+    print_list.append('\nPDB_ID: %s' % pdb_id)
     print_list.append('\nExercise_%s Answer List:' % (idx + 1))
     for i in rmsd.keys():
         print_list.append(i + ':' + str(rmsd[i]))
@@ -23,6 +22,17 @@ def print_answer(user_input, best_mol, rmsd, score, pdb_id, idx):
     return print_list
 
 
+def calc_score(rmsd):
+    rmsd = float(rmsd)
+    if rmsd >= 5:
+        score = 0
+    else:
+        score = -2 * rmsd + 10
+
+    score = int((score - int(score)) * 10)/10 + int(score)
+    return score
+
+
 @click.command()
 @click.option('-n', '--number', type=int, help='Number of Exercise', default=5)
 def run(number):
@@ -42,37 +52,40 @@ def run(number):
         pdb_id_list.append(pdb_dir)
 
     txt_list = []
-    print(f'\nReady, please switch to the {play_dir} directory')
+    print(f'\nReady, please switch to the "{play_dir}" directory')
 
     # get start time
     start = datetime.datetime.now()
 
+    total_score = []
     answer_area = [str(i) for i in range(1, 11)]
     for idx, ans in enumerate(answer):
         rmsd = ans[0]
         best_mol = ans[1]
         pdb_id = pdb_id_list[idx]
         while True:
-            user_input = input('\nInput the mol number of Exercise_%s:' % (idx+1))
+            user_input = input('\nInput the mol number of Exercise %s :' % (idx+1))
             if user_input in answer_area:
                 break
             else:
                 print('Input error!Please input the number!')
 
         # record
-        txt_list.append('Exercise_%s' % (idx + 1))
+        txt_list.append('Exercise %s ' % (idx + 1))
         txt_list.append("User's choice: %s" % user_input)
 
         # calc score
-        score = None
+        score = calc_score(rmsd[user_input])
+        total_score.append(score)
 
         # print_answer
         print_list = print_answer(user_input, best_mol, rmsd, score, pdb_id, idx)
         txt_list.extend(print_list)
         txt_list.append('-------------')
 
-    print('\n\nYour total score: %s' % '待开发')
-    txt_list.append('\n\nTotal score: %s\n' % '待开发')
+    average_score_txt = '\n\nYour average score of %s exercises: %s' % (number, sum(total_score)/number)
+    print(average_score_txt)
+    txt_list.append(average_score_txt)
 
     # get end time and time cost
     end = datetime.datetime.now()
